@@ -37,7 +37,7 @@ class AddSemanticTypesPrimitive(transformer.TransformerPrimitiveBase[Inputs, Out
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': 'd7e14b12-abeb-42d8-942f-bdb077b4fd37',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': "Add semantic types to columns",
             'python_path': 'd3m.primitives.data_transformation.add_semantic_types.Common',
             'source': {
@@ -50,8 +50,8 @@ class AddSemanticTypesPrimitive(transformer.TransformerPrimitiveBase[Inputs, Out
             },
             'installation': [{
                 'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                  metadata_base.PrimitiveAlgorithmType.DATA_CONVERSION,
