@@ -41,7 +41,7 @@ class AudioReaderPrimitive(primitives.FileReaderPrimitiveBase):
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': '05e6eba3-2f5a-4934-8309-a6d17e099400',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': 'Columns audio reader',
             'python_path': 'd3m.primitives.data_transformation.audio_reader.Common',
             'keywords': ['audio', 'reader', 'aiff', 'flac', 'ogg', 'wav', 'mpeg'],
@@ -59,8 +59,8 @@ class AudioReaderPrimitive(primitives.FileReaderPrimitiveBase):
                 'version': '7:2.8.11-0',
             }, {
                 'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.FILE_MANIPULATION,
