@@ -31,7 +31,7 @@ class Hyperparams(hyperparams_module.Hyperparams):
                 #       See: https://gitlab.com/datadrivendiscovery/d3m/issues/214
                 default=typing.cast(
                     typing.Type[transformer.TransformerPrimitiveBase],
-                    index.get_primitive('d3m.primitives.operator.null.TransformerTest')
+                    index.get_primitive('d3m.primitives.operator.null.TransformerCore')
                 ),
                 semantic_types=['https://metadata.datadrivendiscovery.org/types/ControlParameter'],
                 description="A transformer primitive.",
@@ -42,7 +42,7 @@ class Hyperparams(hyperparams_module.Hyperparams):
                 #       See: https://gitlab.com/datadrivendiscovery/d3m/issues/214
                 default=typing.cast(
                     typing.Type[unsupervised_learning.UnsupervisedLearnerPrimitiveBase],
-                    index.get_primitive('d3m.primitives.operator.null.UnsupervisedLearnerTest')
+                    index.get_primitive('d3m.primitives.operator.null.UnsupervisedLearnerCore')
                 ),
                 semantic_types=['https://metadata.datadrivendiscovery.org/types/ControlParameter'],
                 description="An unsupervised learner primitive. If it is already fitted and you do not want to re-fit it, "
@@ -114,7 +114,7 @@ class DataFrameColumnMapPrimitive(unsupervised_learning.UnsupervisedLearnerPrimi
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': 'fe58e7bb-f6c7-4d91-b897-69faf33bece5',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': "Map DataFrame cell values to new values using provided primitive",
             'python_path': 'd3m.primitives.operator.column_map.Common',
             'source': {
@@ -127,8 +127,8 @@ class DataFrameColumnMapPrimitive(unsupervised_learning.UnsupervisedLearnerPrimi
             },
             'installation': [{
                 'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 # TODO: Change to "MAP".
