@@ -35,7 +35,7 @@ class ComputeMetafeaturesPrimitive(transformer.TransformerPrimitiveBase[Inputs,
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': '915832a4-8059-438d-9118-f4fb4f7b0aaf',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': "Compute meta-features",
             'python_path': 'd3m.primitives.metalearning.metafeature_extractor.Common',
             'source': {
@@ -48,8 +48,8 @@ class ComputeMetafeaturesPrimitive(transformer.TransformerPrimitiveBase[Inputs,
             },
             'installation': [{
                'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.DATA_PROFILING,
