@@ -36,7 +36,7 @@ class ComputeUniqueValuesPrimitive(unsupervised_learning.UnsupervisedLearnerPrim
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': 'dd580c45-9fbe-493d-ac79-6e9f706a3619',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': "Add all_distinct_values to the metadata of the input Dataframe",
             'python_path': 'd3m.primitives.operator.compute_unique_values.Common',
             'source': {
@@ -49,8 +49,8 @@ class ComputeUniqueValuesPrimitive(unsupervised_learning.UnsupervisedLearnerPrim
             },
             'installation': [{
                 'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [metadata_base.PrimitiveAlgorithmType.DATA_NORMALIZATION],
             'primitive_family': metadata_base.PrimitiveFamily.OPERATOR,
