@@ -37,7 +37,7 @@ class ConstructConfidencePrimitive(TransformerPrimitiveBase[Inputs, Outputs, Hyp
     __author__ = "JPL DARPA D3M Team, Diego Martinez <dmartinez05@tamu.edu>"
     metadata = metadata_module.PrimitiveMetadata({
         'id': '500c4f0c-a040-48a5-aa76-d6463ea7ea37',
-        "version": "0.1.0",
+        "version": common_primitives.__version__,
         "name": "Construct confidence",
         "source": {
             'name': common_primitives.__author__,
@@ -49,8 +49,8 @@ class ConstructConfidencePrimitive(TransformerPrimitiveBase[Inputs, Outputs, Hyp
         },
         "installation": [{
             'type': metadata_module.PrimitiveInstallationType.PIP,
-            'package': 'd3m-common-primitives',
-            'version': '2022.2.17',
+            'package': 'd3m',
+            'version': '2022.3.28',
         }],
         "python_path": "d3m.primitives.data_transformation.construct_confidence.Common",
         "algorithm_types": [metadata_base.PrimitiveAlgorithmType.DATA_CONVERSION],
