@@ -30,7 +30,7 @@ class CSVReaderPrimitive(primitives.FileReaderPrimitiveBase):
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': '989562ac-b50f-4462-99cb-abef80d765b2',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': 'Columns CSV reader',
             'python_path': 'd3m.primitives.data_transformation.csv_reader.Common',
             'keywords': ['CSV', 'reader'],
@@ -44,8 +44,8 @@ class CSVReaderPrimitive(primitives.FileReaderPrimitiveBase):
             },
             'installation': [{
                 'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.FILE_MANIPULATION,
