@@ -64,7 +64,7 @@ class CutAudioPrimitive(transformer.TransformerPrimitiveBase[Inputs, Outputs, Hy
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': '4ad9ce62-283d-4765-a87b-78b55d89a4ed',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': 'Cut audio columns',
             'python_path': 'd3m.primitives.data_transformation.cut_audio.Common',
             'keywords': ['audio', 'cut'],
@@ -78,8 +78,8 @@ class CutAudioPrimitive(transformer.TransformerPrimitiveBase[Inputs, Outputs, Hy
             },
             'installation': [{
                 'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.ARRAY_SLICING,
