@@ -78,7 +78,7 @@ class DataFrameFlattenPrimitive(transformer.TransformerPrimitiveBase[Inputs, Out
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': '1c4aed23-f3d3-4e6b-9710-009a9bc9b694',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': 'DataFrame Flatten',
             'python_path': 'd3m.primitives.data_transformation.flatten.DataFrameCommon',
             'keywords': ['dataframe', 'flatten'],
@@ -92,8 +92,8 @@ class DataFrameFlattenPrimitive(transformer.TransformerPrimitiveBase[Inputs, Out
             },
             'installation': [{
                'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.DATA_DENORMALIZATION,
