@@ -28,7 +28,7 @@ class DataframeListExtractorPrimitive(transformer.TransformerPrimitiveBase[Input
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': '9fe84601-a3d7-4881-86b2-44fecd42b296',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': 'Select dataframe from list of dataframes',
             'python_path': 'd3m.primitives.data_transformation.dataframe_list_extractor.Common',
             'source': {
@@ -41,8 +41,8 @@ class DataframeListExtractorPrimitive(transformer.TransformerPrimitiveBase[Input
             },
             'installation': [{
                 'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.ARRAY_SLICING,
