@@ -26,7 +26,7 @@ class DataFrameToListPrimitive(transformer.TransformerPrimitiveBase[Inputs, Outp
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': '901ff55d-0a0a-4bfd-8195-3a947ba2a8f5',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': "DataFrame to list converter",
             'python_path': 'd3m.primitives.data_transformation.dataframe_to_list.Common',
             'source': {
@@ -39,8 +39,8 @@ class DataFrameToListPrimitive(transformer.TransformerPrimitiveBase[Inputs, Outp
             },
             'installation': [{
                 'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.DATA_CONVERSION,
