@@ -26,7 +26,7 @@ class DataFrameToNDArrayPrimitive(transformer.TransformerPrimitiveBase[Inputs, O
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': '34f71b2e-17bb-488d-a2ba-b60b8c305539',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': "DataFrame to ndarray converter",
             'python_path': 'd3m.primitives.data_transformation.dataframe_to_ndarray.Common',
             'source': {
@@ -39,8 +39,8 @@ class DataFrameToNDArrayPrimitive(transformer.TransformerPrimitiveBase[Inputs, O
             },
             'installation': [{
                'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.DATA_CONVERSION,
