@@ -55,7 +55,7 @@ class DataMartAugmentPrimitive(TransformerPrimitiveBase[Inputs, Outputs, Hyperpa
 
     metadata = metadata_base.PrimitiveMetadata({
         'id': 'fe0f1ac8-1d39-463a-b344-7bd498a31b91',
-        'version': '0.1',
+        'version': common_primitives.__version__,
         'name': "Perform dataset augmentation using Datamart",
         'python_path': 'd3m.primitives.data_augmentation.datamart_augmentation.Common',
         'source': {
@@ -68,8 +68,8 @@ class DataMartAugmentPrimitive(TransformerPrimitiveBase[Inputs, Outputs, Hyperpa
         },
         'installation': [{
             'type': metadata_base.PrimitiveInstallationType.PIP,
-            'package': 'd3m-common-primitives',
-            'version': '2022.2.17',
+            'package': 'd3m',
+            'version': '2022.3.28',
         }],
         'algorithm_types': [
             metadata_base.PrimitiveAlgorithmType.DATA_RETRIEVAL,
