@@ -35,7 +35,7 @@ class Hyperparams(hyperparams_module.Hyperparams):
                 #       See: https://gitlab.com/datadrivendiscovery/d3m/issues/214
                 default=typing.cast(
                     typing.Type[transformer.TransformerPrimitiveBase],
-                    index.get_primitive('d3m.primitives.operator.null.TransformerTest'),
+                    index.get_primitive('d3m.primitives.operator.null.TransformerCore'),
                 ),
                 semantic_types=['https://metadata.datadrivendiscovery.org/types/ControlParameter'],
                 description="A transformer primitive.",
@@ -46,7 +46,7 @@ class Hyperparams(hyperparams_module.Hyperparams):
                 #       See: https://gitlab.com/datadrivendiscovery/d3m/issues/214
                 default=typing.cast(
                     typing.Type[unsupervised_learning.UnsupervisedLearnerPrimitiveBase],
-                    index.get_primitive('d3m.primitives.operator.null.UnsupervisedLearnerTest'),
+                    index.get_primitive('d3m.primitives.operator.null.UnsupervisedLearnerCore'),
                 ),
                 semantic_types=['https://metadata.datadrivendiscovery.org/types/ControlParameter'],
                 description="An unsupervised learner primitive. If it is already fitted and you do not want to re-fit it, "
@@ -125,7 +125,7 @@ class DataFrameDatasetMapPrimitive(unsupervised_learning.UnsupervisedLearnerPrim
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': '5bef5738-1638-48d6-9935-72445f0eecdc',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': "Map DataFrame resources to new resources using provided primitive",
             'python_path': 'd3m.primitives.operator.dataset_map.DataFrameCommon',
             'source': {
@@ -138,8 +138,8 @@ class DataFrameDatasetMapPrimitive(unsupervised_learning.UnsupervisedLearnerPrim
             },
             'installation': [{
                 'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 # TODO: Change to "MAP".
