@@ -66,13 +66,12 @@ class DatasetSamplePrimitive(transformer.TransformerPrimitiveBase[Inputs, Output
     """
 
     __author__ = 'Distil'
-    __version__ = '0.1.0'
     __contact__ = 'mailto:nklabs@newknowledge.com'
 
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': '268315c1-7549-4aee-a4cc-28921cba74c0',
-            'version': __version__,
+            'version': common_primitives.__version__,
             'name': "Dataset sampling primitive",
             'python_path': 'd3m.primitives.data_transformation.dataset_sample.Common',
             'source': {
@@ -85,8 +84,8 @@ class DatasetSamplePrimitive(transformer.TransformerPrimitiveBase[Inputs, Output
             },
             'installation': [{
                'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.DATA_SPLITTING,
