@@ -43,7 +43,7 @@ class DatetimeFieldComposePrimitive(transformer.TransformerPrimitiveBase[Inputs,
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': '73d79f46-1bea-4858-a061-a2d1cfc5f122',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': "Datetime Field Compose",
             'python_path': 'd3m.primitives.data_transformation.datetime_field_compose.Common',
             'source': {
@@ -56,8 +56,8 @@ class DatetimeFieldComposePrimitive(transformer.TransformerPrimitiveBase[Inputs,
             },
             'installation': [{
                'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.DATA_CONVERSION,
