@@ -30,7 +30,7 @@ class ExtractColumnsPrimitive(transformer.TransformerPrimitiveBase[Inputs, Outpu
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': '81d7e261-e25b-4721-b091-a31cd46e99ae',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': "Extracts columns",
             'python_path': 'd3m.primitives.data_transformation.extract_columns.Common',
             'source': {
@@ -43,8 +43,8 @@ class ExtractColumnsPrimitive(transformer.TransformerPrimitiveBase[Inputs, Outpu
             },
             'installation': [{
                 'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.ARRAY_SLICING,
