@@ -63,7 +63,7 @@ class ExtractColumnsByStructuralTypesPrimitive(transformer.TransformerPrimitiveB
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': '79674d68-9b93-4359-b385-7b5f60645b06',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': "Extracts columns by structural type",
             'python_path': 'd3m.primitives.data_transformation.extract_columns_by_structural_types.Common',
             'source': {
@@ -76,8 +76,8 @@ class ExtractColumnsByStructuralTypesPrimitive(transformer.TransformerPrimitiveB
             },
             'installation': [{
                 'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.ARRAY_SLICING,
