@@ -43,7 +43,7 @@ class FixedSplitDatasetSplitPrimitive(primitives.TabularSplitPrimitiveBase[Hyper
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': '1654f000-2178-4520-be4c-a95bc26b8d3a',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': "Fixed split tabular dataset splits",
             'python_path': 'd3m.primitives.evaluation.fixed_split_dataset_split.Commmon',
             'source': {
@@ -56,8 +56,8 @@ class FixedSplitDatasetSplitPrimitive(primitives.TabularSplitPrimitiveBase[Hyper
             },
             'installation': [{
                'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.DATA_SPLITTING,
