@@ -52,7 +52,7 @@ class GroupingFieldComposePrimitive(transformer.TransformerPrimitiveBase[Inputs,
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': '59db88b9-dd81-4e50-8f43-8f2af959560b',
-            'version': '0.1.1',
+            'version': common_primitives.__version__,
             'name': "Grouping Field Compose",
             'python_path': 'd3m.primitives.data_transformation.grouping_field_compose.Common',
             'source': {
@@ -65,8 +65,8 @@ class GroupingFieldComposePrimitive(transformer.TransformerPrimitiveBase[Inputs,
             },
             'installation': [{
                'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.DATA_CONVERSION,
