@@ -53,8 +53,8 @@ class HorizontalConcatPrimitive(transformer.TransformerPrimitiveBase[Inputs, Out
             },
             'installation': [{
                 'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.ARRAY_CONCATENATION,
