@@ -48,7 +48,7 @@ class KFoldDatasetSplitPrimitive(primitives.TabularSplitPrimitiveBase[Hyperparam
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': 'bfedaf3a-6dd0-4a83-ad83-3a50fe882bf8',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': "K-fold cross-validation tabular dataset splits",
             'python_path': 'd3m.primitives.evaluation.kfold_dataset_split.Common',
             'source': {
@@ -61,8 +61,8 @@ class KFoldDatasetSplitPrimitive(primitives.TabularSplitPrimitiveBase[Hyperparam
             },
             'installation': [{
                'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.K_FOLD,
