@@ -110,8 +110,8 @@ class KFoldTimeSeriesSplitPrimitive(primitives.TabularSplitPrimitiveBase[Hyperpa
             'installation': [
                 {
                     'type': metadata_base.PrimitiveInstallationType.PIP,
-                    'package': 'd3m-common-primitives',
-                    'version': '2022.2.17',
+                    'package': 'd3m',
+                    'version': '2022.3.28',
                 }
             ],
             'algorithm_types': [
