@@ -253,7 +253,7 @@ class LightGBMClassifierPrimitive(ProbabilisticCompositionalityMixin[Inputs, Out
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': '259aa747-795c-435e-8e33-8c32a4c83c6b',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': "LightGBM GBTree classifier",
             'python_path': 'd3m.primitives.classification.light_gbm.Common',
             'keywords': ['lightgbm', 'decision tree', 'gradient boosted trees', ],
@@ -266,8 +266,8 @@ class LightGBMClassifierPrimitive(ProbabilisticCompositionalityMixin[Inputs, Out
             },
             'installation': [{
                 'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.GRADIENT_BOOSTING,
