@@ -25,7 +25,7 @@ class ListToDataFramePrimitive(transformer.TransformerPrimitiveBase[Inputs, Outp
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': 'dd4598cf-2384-438a-a264-f6c77185132b',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': "List to DataFrame converter",
             'python_path': 'd3m.primitives.data_transformation.list_to_dataframe.Common',
             'source': {
@@ -38,8 +38,8 @@ class ListToDataFramePrimitive(transformer.TransformerPrimitiveBase[Inputs, Outp
             },
             'installation': [{
                 'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.DATA_CONVERSION,
