@@ -26,7 +26,7 @@ class ListToNDArrayPrimitive(transformer.TransformerPrimitiveBase[Inputs, Output
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': '40ff1396-0725-4cf9-b7b9-c6eca6237f65',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': "List to ndarray converter",
             'python_path': 'd3m.primitives.data_transformation.list_to_ndarray.Common',
             'source': {
@@ -39,8 +39,8 @@ class ListToNDArrayPrimitive(transformer.TransformerPrimitiveBase[Inputs, Output
             },
             'installation': [{
                 'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.DATA_CONVERSION,
