@@ -27,7 +27,7 @@ class HorizontalConcatListPrimitive(transformer.TransformerPrimitiveBase[Inputs,
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': '3e53391c-74aa-443f-bf2a-8890f3e7d7b6',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': "Concatenate multiple dataframes",
             'python_path': 'd3m.primitives.data_transformation.multi_horizontal_concat.Common',
             'source': {
@@ -40,8 +40,8 @@ class HorizontalConcatListPrimitive(transformer.TransformerPrimitiveBase[Inputs,
             },
             'installation': [{
                 'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.ARRAY_CONCATENATION,
