@@ -26,7 +26,7 @@ class NDArrayToDataFramePrimitive(transformer.TransformerPrimitiveBase[Inputs, O
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': 'f5241b2e-64f7-44ad-9675-df3d08066437',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': "ndarray to Dataframe converter",
             'python_path': 'd3m.primitives.data_transformation.ndarray_to_dataframe.Common',
             'source': {
@@ -39,8 +39,8 @@ class NDArrayToDataFramePrimitive(transformer.TransformerPrimitiveBase[Inputs, O
             },
             'installation': [{
                 'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.DATA_CONVERSION,
