@@ -25,7 +25,7 @@ class NDArrayToListPrimitive(transformer.TransformerPrimitiveBase[Inputs, Output
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': 'b5101331-64b4-451a-beb6-260b40d1436b',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': "ndarray to list converter",
             'python_path': 'd3m.primitives.data_transformation.ndarray_to_list.Common',
             'source': {
@@ -38,8 +38,8 @@ class NDArrayToListPrimitive(transformer.TransformerPrimitiveBase[Inputs, Output
             },
             'installation': [{
                 'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.DATA_CONVERSION,
