@@ -26,7 +26,7 @@ class NoSplitDatasetSplitPrimitive(primitives.TabularSplitPrimitiveBase[Hyperpar
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': '48c683ad-da9e-48cf-b3a0-7394dba5e5d2',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': "No-split tabular dataset splits",
             'python_path': 'd3m.primitives.evaluation.no_split_dataset_split.Common',
             'source': {
@@ -39,8 +39,8 @@ class NoSplitDatasetSplitPrimitive(primitives.TabularSplitPrimitiveBase[Hyperpar
             },
             'installation': [{
                'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.IDENTITY_FUNCTION,
