@@ -33,7 +33,7 @@ class NormalizeColumnReferencesPrimitive(transformer.TransformerPrimitiveBase[In
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': '2ee36ea4-5ec3-4c18-909f-9e157fb6d18f',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': "Normalize column references",
             'python_path': 'd3m.primitives.data_transformation.normalize_column_references.Common',
             'source': {
@@ -46,8 +46,8 @@ class NormalizeColumnReferencesPrimitive(transformer.TransformerPrimitiveBase[In
             },
             'installation': [{
                'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.DATA_CONVERSION,
