@@ -64,7 +64,7 @@ class NumericRangeFilterPrimitive(transformer.TransformerPrimitiveBase[Inputs, O
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': '8c246c78-3082-4ec9-844e-5c98fcc76f9d',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': "Numeric range filter",
             'python_path': 'd3m.primitives.data_transformation.numeric_range_filter.Common',
             'source': {
@@ -77,8 +77,8 @@ class NumericRangeFilterPrimitive(transformer.TransformerPrimitiveBase[Inputs, O
             },
             'installation': [{
                 'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.ARRAY_SLICING,
