@@ -114,8 +114,8 @@ class OneHotMakerPrimitive(UnsupervisedLearnerPrimitiveBase[Inputs, Outputs, Par
         },
         'installation': [{
             'type': metadata_module.PrimitiveInstallationType.PIP,
-            'package': 'd3m-common-primitives',
-            'version': '2022.2.17',
+            'package': 'd3m',
+            'version': '2022.3.28',
         }],
         'python_path': 'd3m.primitives.data_transformation.one_hot_encoder.MakerCommon',
         'algorithm_types': [
