@@ -73,7 +73,7 @@ class PandasOneHotEncoderPrimitive(UnsupervisedLearnerPrimitiveBase[Inputs, Outp
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': 'f6315ca9-ca39-4e13-91ba-1964ee27281c',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': "Pandas one hot encoder",
             'python_path': 'd3m.primitives.data_transformation.one_hot_encoder.PandasCommon',
             'source': {
@@ -86,8 +86,8 @@ class PandasOneHotEncoderPrimitive(UnsupervisedLearnerPrimitiveBase[Inputs, Outp
             },
             'installation': [{
                 'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.ENCODE_ONE_HOT,
