@@ -31,7 +31,7 @@ class RavelAsRowPrimitive(transformer.TransformerPrimitiveBase[Inputs, Outputs,
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': 'fe87544d-ef93-48d0-b420-76768d351f39',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': "Ravel a DataFrame into a row",
             'python_path': 'd3m.primitives.data_transformation.ravel.DataFrameRowCommon',
             'source': {
@@ -44,8 +44,8 @@ class RavelAsRowPrimitive(transformer.TransformerPrimitiveBase[Inputs, Outputs,
             },
             'installation': [{
                 'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.ARRAY_CONCATENATION,
