@@ -41,7 +41,7 @@ class RegexFilterPrimitive(transformer.TransformerPrimitiveBase[Inputs, Outputs,
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': 'cf73bb3d-170b-4ba9-9ead-3dd4b4524b61',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': "Regex dataset filter",
             'python_path': 'd3m.primitives.data_transformation.regex_filter.Common',
             'source': {
@@ -54,8 +54,8 @@ class RegexFilterPrimitive(transformer.TransformerPrimitiveBase[Inputs, Outputs,
             },
             'installation': [{
                'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.ARRAY_SLICING,
