@@ -29,7 +29,7 @@ class RemoveColumnsPrimitive(transformer.TransformerPrimitiveBase[Inputs, Output
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': '3b09ba74-cc90-4f22-9e0a-0cf4f29a7e28',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': "Removes columns",
             'python_path': 'd3m.primitives.data_transformation.remove_columns.Common',
             'source': {
@@ -42,8 +42,8 @@ class RemoveColumnsPrimitive(transformer.TransformerPrimitiveBase[Inputs, Output
             },
             'installation': [{
                 'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.ARRAY_SLICING,
