@@ -46,7 +46,7 @@ class RemoveDuplicateColumnsPrimitive(unsupervised_learning.UnsupervisedLearnerP
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': '130513b9-09ca-4785-b386-37ab31d0cf8b',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': "Removes duplicate columns",
             'python_path': 'd3m.primitives.data_transformation.remove_duplicate_columns.Common',
             'source': {
@@ -59,8 +59,8 @@ class RemoveDuplicateColumnsPrimitive(unsupervised_learning.UnsupervisedLearnerP
             },
             'installation': [{
                 'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.ARRAY_SLICING,
