@@ -37,7 +37,7 @@ class RemoveSemanticTypesPrimitive(transformer.TransformerPrimitiveBase[Inputs,
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': '3002bc5b-fa47-4a3d-882e-a8b5f3d756aa',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': "Remove semantic types from columns",
             'python_path': 'd3m.primitives.data_transformation.remove_semantic_types.Common',
             'source': {
@@ -50,8 +50,8 @@ class RemoveSemanticTypesPrimitive(transformer.TransformerPrimitiveBase[Inputs,
             },
             'installation': [{
                 'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.DATA_CONVERSION,
