@@ -42,7 +42,7 @@ class StackNDArrayColumnPrimitive(transformer.TransformerPrimitiveBase[Inputs, O
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': '48c99864-14f3-4a61-b3a6-e439f22825f6',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': "Stack numpy arrays in a column",
             'python_path': 'd3m.primitives.data_transformation.stack_ndarray_column.Common',
             'source': {
@@ -55,8 +55,8 @@ class StackNDArrayColumnPrimitive(transformer.TransformerPrimitiveBase[Inputs, O
             },
             'installation': [{
                 'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.ARRAY_CONCATENATION,
