@@ -57,7 +57,7 @@ class AnnotatedTabularExtractorPrimitive(unsupervised_learning.UnsupervisedLearn
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': '6c425897-6ffe-45b8-949f-002d872ccf12',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': 'Annotated tabular extractor',
             'python_path': 'd3m.primitives.data_cleaning.tabular_extractor.Common',
             'source': {
@@ -70,8 +70,8 @@ class AnnotatedTabularExtractorPrimitive(unsupervised_learning.UnsupervisedLearn
             },
             'installation': [{
                 'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.IMPUTATION,
