@@ -48,7 +48,7 @@ class TermFilterPrimitive(transformer.TransformerPrimitiveBase[Inputs, Outputs,
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': 'a6b27300-4625-41a9-9e91-b4338bfc219b',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': "Term list dataset filter",
             'python_path': 'd3m.primitives.data_transformation.term_filter.Common',
             'source': {
@@ -61,8 +61,8 @@ class TermFilterPrimitive(transformer.TransformerPrimitiveBase[Inputs, Outputs,
             },
             'installation': [{
                 'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.ARRAY_SLICING,
