@@ -28,7 +28,7 @@ class TextReaderPrimitive(primitives.FileReaderPrimitiveBase):
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': '0b21fcca-8b35-457d-a65d-36294c6f80a2',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': 'Columns text reader',
             'python_path': 'd3m.primitives.data_transformation.text_reader.Common',
             'keywords': ['text', 'reader', 'plain'],
@@ -42,8 +42,8 @@ class TextReaderPrimitive(primitives.FileReaderPrimitiveBase):
             },
             'installation': [{
                 'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.FILE_MANIPULATION,
