@@ -48,7 +48,7 @@ class TrainScoreDatasetSplitPrimitive(primitives.TabularSplitPrimitiveBase[Hyper
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': '3fcc6dc4-6681-4c86-948e-066d14e7d803',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': "Train-score tabular dataset splits",
             'python_path': 'd3m.primitives.evaluation.train_score_dataset_split.Common',
             'source': {
@@ -61,8 +61,8 @@ class TrainScoreDatasetSplitPrimitive(primitives.TabularSplitPrimitiveBase[Hyper
             },
             'installation': [{
                'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.HOLDOUT,
