@@ -58,7 +58,7 @@ class UnseenLabelDecoderPrimitive(TransformerPrimitiveBase[Inputs, Outputs, Hype
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': '39ae30f7-39ed-40af-8679-5cf108499605',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': "Label decoder for UnseenLabelEncoderPrimitive",
             'python_path': 'd3m.primitives.data_transformation.label_decoder.Common',
             'source': {
@@ -71,8 +71,8 @@ class UnseenLabelDecoderPrimitive(TransformerPrimitiveBase[Inputs, Outputs, Hype
             },
             'installation': [{
                 'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.CATEGORY_ENCODER,
