@@ -51,8 +51,8 @@ class VideoReaderPrimitive(primitives.FileReaderPrimitiveBase):
             'installation': [
                 {
                     'type': metadata_base.PrimitiveInstallationType.PIP,
-                    'package': 'd3m-common-primitives',
-                    'version': '2022.2.17',
+                    'package': 'd3m',
+                    'version': '2022.3.28',
                 },
                 {
                     'type': metadata_base.PrimitiveInstallationType.PIP,
