@@ -272,7 +272,7 @@ class XGBoostDartClassifierPrimitive(ProbabilisticCompositionalityMixin[Inputs,
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': '7476950e-4373-4cf5-a852-7e16afb8e098',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': "XGBoost DART classifier",
             'python_path': 'd3m.primitives.classification.xgboost_dart.Common',
             'keywords': ['xgboost', 'decision tree', 'gradient boosted trees', ],
@@ -285,8 +285,8 @@ class XGBoostDartClassifierPrimitive(ProbabilisticCompositionalityMixin[Inputs,
             },
             'installation': [{
                 'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.GRADIENT_BOOSTING,
