@@ -253,7 +253,7 @@ class XGBoostGBTreeClassifierPrimitive(ProbabilisticCompositionalityMixin[Inputs
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': 'fe0841b7-6e70-4bc3-a56c-0670a95ebc6a',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': "XGBoost GBTree classifier",
             'python_path': 'd3m.primitives.classification.xgboost_gbtree.Common',
             'keywords': ['xgboost', 'decision tree', 'gradient boosted trees', ],
@@ -266,8 +266,8 @@ class XGBoostGBTreeClassifierPrimitive(ProbabilisticCompositionalityMixin[Inputs
             },
             'installation': [{
                 'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.GRADIENT_BOOSTING,
