@@ -246,7 +246,7 @@ class XGBoostGBTreeRegressorPrimitive(SamplingCompositionalityMixin[Inputs, Outp
     metadata = metadata_base.PrimitiveMetadata(
         {
             'id': 'cdbb80e4-e9de-4caa-a710-16b5d727b959',
-            'version': '0.1.0',
+            'version': common_primitives.__version__,
             'name': "XGBoost GBTree regressor",
             'python_path': 'd3m.primitives.regression.xgboost_gbtree.Common',
             'keywords': ['xgboost', 'decision tree', 'gradient boosted trees', ],
@@ -259,8 +259,8 @@ class XGBoostGBTreeRegressorPrimitive(SamplingCompositionalityMixin[Inputs, Outp
             },
             'installation': [{
                 'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m-common-primitives',
-                'version': '2022.2.17',
+                'package': 'd3m',
+                'version': '2022.3.28',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.GRADIENT_BOOSTING,
